****************************************************************************
*                                                                           *
* This file contains two functions which can be used to circumvent the lack *
* of SET EPOCH TO in Clipper Summer '87                                     *
* It is put into the PUBLIC DOMAIN by Roderick McLeod - 16th December 1997  *
* EMAIL Queries or comments to roderickmcleod@cix.co.uk                     *
*                                                                           *
*****************************************************************************
*
* Notes
*
*   The Functions assume the availability of a PUBLIC variable called
*   'epoch_nc' which should be used as in SET EPOCH TO in Clipper 5.
*   For example the statements
*
*                    PUBLIC epoch_nc
*                    epoch_nc=1980
*                                        
*   will allow two digit years to be used in the range 1980-2079
*
*   The functions assume that SET CENTURY is OFF
*  
*   The functions will operate with all Summer '87 date formats apart
*   from SET DATE ANSI. 
******************************************************************************
FUNCTION ctod_nc
PARAMETER qdate_nc
PRIVATE lowcen_nc,highcen_nc,change_nc
IF LEN(qdate_nc)=10
RETURN CTOD(qdate_nc)                                  && date includes century
ENDIF
lowcen_nc=INT(epoch_nc/100)
highcen_nc=lowcen_nc+1
change_nc=epoch_nc-(lowcen_nc*100)
IF VAL(RIGHT(qdate_nc,2))>=change_nc
RETURN CTOD(LEFT(qdate_nc,6)+STR(lowcen_nc,2)+RIGHT(qdate_nc,2))
ENDIF
RETURN CTOD(LEFT(qdate_nc,6)+STR(highcen_nc,2)+RIGHT(qdate_nc,2))
******************************************************************************
FUNCTION date_nc
*qindate is a charater string which contains a temporary copy of the date
*qoutdate is a character string containing the name of the date variable or
*   field. Note that the field must be in the form ALIAS->FILEDNAME
*qcond is optional. It is a character string containing a condition to 
*be used to validate the resulting date
PARAMETER qin_nc,qout_nc,qcond_nc
PRIVATE qd_nc,qhold_nc,qfield_nc,qi_nc
qfield_nc=""
qp_nc=1
FOR qi_nc=1 TO LEN(qout_nc)
IF .NOT. EMPTY(SUBSTR(qout_nc,qi_nc,1))
qfield_nc=qfield_nc+UPPER(SUBSTR(qout_nc,qi_nc,1))
ENDIF
IF LEN(qfield_nc)=2
EXIT
ENDIF
NEXT
* qfield_nc now contains UPPER case of first two characters of qout_nc
qhold_nc=&qout_nc                    && hold a copy in case condition fails
qd_nc=ctod_nc(qin_nc)
IF DTOC(qd_nc)<>qin_nc
RETURN .F.
ENDIF
IF "-" $ qout_nc .AND. .NOT. qfield_nc=="M-"
REPLACE &qout_nc WITH qd_nc
ELSE
&qout_nc=qd_nc
ENDIF
IF PCOUNT()>2
IF .NOT. &qcond_nc                      && Condition fails - reset qoutdate
IF "-" $ qout_nc .AND. .NOT. qfield_nc=="M-"
REPLACE &qout_nc WITH qhold_nc
ELSE
&qout_nc=qhold_nc
ENDIF
RETURN .F.
ENDIF
ENDIF
RETURN .T.
*******************************************************************************